==> pexy-0.9.0.tar.gz: pexy-0.9.0/src/pexy/command/__init__.py <==
# MIT License
#
# Copyright (c) 2024 Clivern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from .store import StoreInfo as StoreInfoCommand
from .access import AccessScopes as AccessScopesCommand
from .product import (
    ListAllProducts as ListAllProductsCommand,
    ListSomeProducts as ListSomeProductsCommand,
    GetProduct as GetProductCommand,
    CreateProduct as CreateProductCommand,
    UpdateProduct as UpdateProductCommand,
    DeleteProduct as DeleteProductCommand,
    CountProducts as CountProductsCommand,
)

==> pexy-0.9.3.tar.gz: pexy-0.9.3/src/pexy/command/__init__.py <==
# MIT License
#
# Copyright (c) 2024 Clivern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from .store import StoreInfo as StoreInfoCommand
from .access import AccessScopes as AccessScopesCommand
from .product import (
    ListProducts as ListProductsCommand,
    GetProduct as GetProductCommand,
    CreateProduct as CreateProductCommand,
    UpdateProduct as UpdateProductCommand,
    DeleteProduct as DeleteProductCommand,
    CountProducts as CountProductsCommand,
)
from .collection import (
    CreateCollection as CreateCollectionCommand,
    UpdateCollection as UpdateCollectionCommand,
    ListCollection as ListCollectionCommand,
    GetCollection as GetCollectionCommand,
    CountCollection as CountCollectionCommand,
    DeleteCollection as DeleteCollectionCommand,
)
